<?php
/**
 * Shipping Calculator
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.4.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( 'no' === get_option( 'woocommerce_enable_shipping_calc' ) || ! WC()->cart->needs_shipping() ) {
	return;
}

global $venedor_woo_version;

wp_enqueue_script( 'wc-country-select' );

do_action( 'woocommerce_before_shipping_calculator' ); ?>

<div class="woocommerce-shipping-calculator shipping_calculator">

	<h2><?php _e( 'Calculate Shipping', 'venedor' ); ?></h2>

	<section class="shipping-calculator-form" style="display:none;">

		<p class="form-row form-row-wide input-field">
            <label for="calc_shipping_country"><span class="fa fa-globe"></span><?php _e( 'Country', 'venedor' ); ?></label>
			<select name="calc_shipping_country" id="calc_shipping_country" class="country_to_state" rel="calc_shipping_state">
				<option value=""><?php _e( 'Select a country&hellip;', 'venedor' ); ?></option>
				<?php
					foreach( WC()->countries->get_shipping_countries() as $key => $value )
						echo '<option value="' . esc_attr( $key ) . '"' . selected( WC()->customer->get_shipping_country(), esc_attr( $key ), false ) . '>' . esc_html( $value ) . '</option>';
				?>
			</select>
		</p>
		
		<?php if ( apply_filters( 'woocommerce_shipping_calculator_enable_state', true ) ) : ?>
		
			<p class="form-row form-row-wide input-field">
				<label for="calc_shipping_state"><span class="fa fa-flag"></span><?php _e( 'State / county', 'venedor' ); ?></label>
				<?php
					$current_cc = WC()->customer->get_shipping_country();
					$current_r  = WC()->customer->get_shipping_state();
					$states     = WC()->countries->get_states( $current_cc );

					// Hidden Input
					if ( is_array( $states ) && empty( $states ) ) {

						?><input type="hidden" name="calc_shipping_state" id="calc_shipping_state" placeholder="<?php esc_attr_e( 'State / county', 'venedor' ); ?>" /><?php

					// Dropdown Input
					} elseif ( is_array( $states ) ) {

						?><span>
							<select name="calc_shipping_state" class="state_select" id="calc_shipping_state" placeholder="<?php esc_attr_e( 'State / county', 'venedor' ); ?>">
								<option value=""><?php _e( 'Select a state&hellip;', 'venedor' ); ?></option>
								<?php
									foreach ( $states as $ckey => $cvalue )
										echo '<option value="' . esc_attr( $ckey ) . '" ' . selected( $current_r, $ckey, false ) . '>' . __( esc_html( $cvalue ), 'venedor' ) .'</option>';
								?>
							</select>
						</span><?php

					// Standard Input
					} else {

						?><input type="text" class="input-text" value="<?php echo esc_attr( $current_r ); ?>" placeholder="<?php esc_attr_e( 'State / county', 'venedor' ); ?>" name="calc_shipping_state" id="calc_shipping_state" /><?php

					}
				?>
			</p>

		<?php endif; ?>
		
		<?php if ( apply_filters( 'woocommerce_shipping_calculator_enable_city', false ) ) : ?>

			<p class="form-row form-row-wide input-field">
                <label for="calc_shipping_city"><span class="fa fa-building-o"></span><?php _e( 'City', 'venedor' ); ?></label>
				<input type="text" class="input-text" value="<?php echo esc_attr( WC()->customer->get_shipping_city() ); ?>" placeholder="<?php esc_attr_e( 'City', 'venedor' ); ?>" name="calc_shipping_city" id="calc_shipping_city" />
			</p>

		<?php endif; ?>

		<?php if ( apply_filters( 'woocommerce_shipping_calculator_enable_postcode', true ) ) : ?>

			<p class="form-row form-row-wide input-field">
                <label for="calc_shipping_postcode"><span class="fa fa-truck"></span><?php _e( 'Postcode / ZIP', 'venedor' ); ?></label>
				<input type="text" class="input-text" value="<?php echo esc_attr( WC()->customer->get_shipping_postcode() ); ?>" placeholder="<?php esc_attr_e( 'Postcode / Zip', 'venedor' ); ?>" name="calc_shipping_postcode" id="calc_shipping_postcode" />
			</p>

		<?php endif; ?>

		<p class="clearfix button-row"><button type="submit" name="calc_shipping" value="1" class="button btn-lg"><?php _e( 'Update Totals', 'venedor' ); ?></button></p>
		
		<?php 
		if ( version_compare($venedor_woo_version, '3.4.0', '<') )
			wp_nonce_field( 'woocommerce-cart' );
		else
			wp_nonce_field( 'woocommerce-shipping-calculator', 'woocommerce-shipping-calculator-nonce' );
		?>
		
		
		<?php  ?>
	</section>
</div>

<?php do_action( 'woocommerce_after_shipping_calculator' ); ?>