<?php
/**
 * Pay for order form
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.4.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $venedor_woo_version;

$totals = $order->get_order_item_totals();
?>
<form id="order_review" method="post">

	<table class="shop_table">
		<thead>
			<tr>
				<th class="product-name"><?php esc_html_e( 'Product', 'venedor' ); ?></th>
				<th class="product-quantity"><?php esc_html_e( 'Qty', 'venedor' ); ?></th>
				<th class="product-total"><?php esc_html_e( 'Totals', 'venedor' ); ?></th>
			</tr>
		</thead>
		<tbody>
            <?php if ( count( $order->get_items() ) > 0 ) : ?>
                <?php foreach ( $order->get_items() as $item ) : ?>
                    <tr>
                        <td class="product-name">
                            <?php echo esc_html( $item['name'] ); ?>
                            <?php $order->display_item_meta( $item ); ?>
                        </td>
                        <td class="product-quantity"><?php echo esc_html( $item['qty'] ); ?></td>
                        <td class="product-subtotal"><?php echo $order->get_formatted_line_subtotal( $item ); ?></td>
                    </tr>
                <?php endforeach; ?>
            <?php endif; ?>
		</tbody>
        <tfoot>
        <?php if ( $totals ) : ?>
            <?php foreach ( $totals as $total ) : ?>
                <tr>
                    <th scope="row" colspan="2"><?php echo $total['label']; ?></th>
                    <td class="product-total"><?php echo $total['value']; ?></td>
                </tr>
            <?php endforeach; ?>
        <?php endif; ?>
        </tfoot>
    </table>

	<div id="payment">
		<?php if ( $order->needs_payment() ) : ?>
		<ul class="wc_payment_methods payment_methods methods">
            <?php if ( version_compare($venedor_woo_version, '2.5', '<') ) : ?>
                <?php
                    if ( $available_gateways = WC()->payment_gateways->get_available_payment_gateways() ) {
                        // Chosen Method
                        if ( sizeof( $available_gateways ) ) {
                            current( $available_gateways )->set_current();
                        }

                        foreach ( $available_gateways as $gateway ) {
                            ?>
                            <li class="payment_method_<?php echo $gateway->id; ?>">
                                <input id="payment_method_<?php echo $gateway->id; ?>" type="radio" class="input-radio" name="payment_method" value="<?php echo esc_attr( $gateway->id ); ?>" <?php checked( $gateway->chosen, true ); ?> data-order_button_text="<?php echo esc_attr( $gateway->order_button_text ); ?>" />
                                <label for="payment_method_<?php echo $gateway->id; ?>"><?php echo $gateway->get_title(); ?> <?php echo $gateway->get_icon(); ?></label>
                                <?php
                                    if ( $gateway->has_fields() || $gateway->get_description() ) {
                                        echo '<div class="payment_box payment_method_' . $gateway->id . '" style="display:none;">';
                                        $gateway->payment_fields();
                                        echo '</div>';
                                    }
                                ?>
                            </li>
                            <?php
                        }
                    } else {

                        echo '<li>'.__( 'Sorry, it seems that there are no available payment methods for your location. Please contact us if you require assistance or wish to make alternate arrangements.', 'venedor' ).'</li>';

                    }
                ?>
            <?php else : ?>
                <?php
                if ( ! empty( $available_gateways ) ) {
                    foreach ( $available_gateways as $gateway ) {
                        wc_get_template( 'checkout/payment-method.php', array( 'gateway' => $gateway ) );
                    }
                } else {
                    echo '<li>' . apply_filters( 'woocommerce_no_available_payment_methods_message', __( 'Sorry, it seems that there are no available payment methods for your location. Please contact us if you require assistance or wish to make alternate arrangements.', 'venedor' ) ) . '</li>';
                }
                ?>
            <?php endif; ?>
		</ul>
		<?php endif; ?>

		<div class="form-row button-row">
            <?php if ( version_compare($venedor_woo_version, '2.5', '<') ) : ?>
                <?php wp_nonce_field( 'woocommerce-pay' ); ?>
                <?php
                    $pay_order_button_text = apply_filters( 'woocommerce_pay_order_button_text', __( 'Pay for order', 'venedor' ) );

                    echo apply_filters( 'woocommerce_pay_order_button_html', '<input type="submit" class="button alt btn-lg" id="place_order" value="' . esc_attr( $pay_order_button_text ) . '" data-value="' . esc_attr( $pay_order_button_text ) . '" />' );
                ?>
                <input type="hidden" name="woocommerce_pay" value="1" />
            <?php else : ?>
                <input type="hidden" name="woocommerce_pay" value="1" />

                <?php wc_get_template( 'checkout/terms.php' ); ?>

                <?php do_action( 'woocommerce_pay_order_before_submit' ); ?>

				<?php echo apply_filters( 'woocommerce_pay_order_button_html', '<button type="submit" class="button alt btn-lg" id="place_order" value="' . esc_attr( $order_button_text ) . '" data-value="' . esc_attr( $order_button_text ) . '">' . esc_html( $order_button_text ) . '</button>' ); // @codingStandardsIgnoreLine ?>

                <?php do_action( 'woocommerce_pay_order_after_submit' ); ?>
				<?php 
				if ( version_compare($venedor_woo_version, '3.4.0', '<') )
					wp_nonce_field( 'woocommerce-pay' );
				else
					wp_nonce_field( 'woocommerce-pay', 'woocommerce-pay-nonce' );
				?>
            <?php endif; ?>
		</div>

	</div>

</form>